/*!
 * @file lux19hs_dng_constants.h
 * @brief Luxima 19HS specific definitions.
 *
 * Copyright 2019 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef __LUX19HS_DNG_CONSTANTS_H__
#define __LUX19HS_DNG_CONSTANTS_H__

#include <stdint.h>

#if 0
// The camera values for 'as-shot' settings (Red, Green, Blue channels).
//
// The "calibrated" values are the "pure" XYZ values back converted to what the
// sensor values "would have been".
//
// The "raw" values are the values actually taken by the sensor.
static int32_t  lux19hs_as_day_calib[] = { 0.624956, 0.985187, 0.699807 };
static int32_t  lux19hs_as_day_raw[] = { 0.654008, 1.0, 0.801688 };

static int32_t  lux19hs_as_cwf_calib[] = { 0.693496, 1.009146, 0.446629 };
static int32_t  lux19hs_as_cwf_raw[] = { 0.711765, 1.0, 0.5 };

static int32_t  lux19hs_as_tun_calib[] = { 1.023146, 0.995655, 0.406675 };
static int32_t  lux19hs_as_tun_raw[] = { 1.0, 0.926380, 0.417178 };
#endif

// Defines the value we use as the calibration illuminant1 (StdA)
#define LUX19HS_CALIBRATION_ILLUMINANT1       17

// Defines the value we use as the calibration illuminant2 (D65)
#define LUX19HS_CALIBRATION_ILLUMINANT2       21

// =============================================================
//
// Make sure this is defined when you are taking calibration
// images. Don't forget to undefine it after!
//
// #define CCM_CALIBRATION 1
//
// =============================================================
#ifdef CCM_CALIBRATION

// The color matrix for Illuniant1. For calibration we want this
// to be the "unity" matrix.
static const int32_t lux19hs_dng_color_matrix1[] =
{
    1000000, 1000000,          0, 1000000,        0, 1000000,
    0, 1000000,    1000000, 1000000,        0, 1000000,
    0, 1000000,          0, 1000000,  1000000, 1000000
};

// The color matrix for Illuminant2. For calibration we want this
// to be the "unity" matrix.
static const int32_t lux19hs_dng_color_matrix2[] =
{
    1000000, 1000000,          0, 1000000,        0, 1000000,
    0, 1000000,    1000000, 1000000,        0, 1000000,
    0, 1000000,          0, 1000000,  1000000, 1000000
};
#else

// The color matrix for Illuniant1.
static const int32_t lux19hs_dng_color_matrix1[] =
{
    3137058, 1000000,  -2195343, 1000000,   614028, 1000000,
    325240, 1000000,   1151203, 1000000,   -28733, 1000000,
    509352, 1000000,    -14248, 1000000,  1277007, 1000000
};

// The color matrix for Illuminant2.
static const int32_t lux19hs_dng_color_matrix2[] =
{
    1437954, 1000000,   -885787, 1000000,   645537, 1000000,
    58829, 1000000,    856181, 1000000,   997793, 1000000,
    392313, 1000000,   -105216, 1000000,  2525576, 1000000
};
#endif /* !CCM_CALIBRATION */

#endif /* __LUX19HS_DNG_CONSTANTS_H__ */
